@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import optparse
 import os.path
@@ -11,10 +11,10 @@ from debian_linux.kconfig import *
 def merge(output, configs, overrides):
     kconfig = KconfigFile()
     for c in configs:
-        kconfig.read(file(c))
-    for key, value in overrides.iteritems():
+        kconfig.read(open(c))
+    for key, value in overrides.items():
         kconfig.set(key, value)
-    file(output, "w").write(str(kconfig))
+    open(output, "w").write(str(kconfig))
 
 
 def opt_callback_dict(option, opt, value, parser):
@@ -28,13 +28,14 @@ def opt_callback_dict(option, opt, value, parser):
 
 if __name__ == '__main__':
     parser = optparse.OptionParser(usage="%prog [OPTION]... FILE...")
-    parser.add_option('-o', '--override',
-            action='callback',
-            callback=opt_callback_dict,
-            default={},
-            dest='overrides',
-            help="Override option",
-            type='string')
+    parser.add_option(
+        '-o', '--override',
+        action='callback',
+        callback=opt_callback_dict,
+        default={},
+        dest='overrides',
+        help="Override option",
+        type='string')
     options, args = parser.parse_args()
 
     merge(args[0], args[1:], options.overrides)
